"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PackageJsonProjectsNextToProjectJsonPlugin = void 0;
const path_1 = require("path");
const fs_1 = require("fs");
const fileutils_1 = require("../../../utils/fileutils");
const package_json_1 = require("../../../utils/package-json");
const package_json_workspaces_1 = require("../../package-json-workspaces");
// TODO: Remove this one day, this should not need to be done.
exports.PackageJsonProjectsNextToProjectJsonPlugin = {
    // Its not a problem if plugins happen to have same name, and this
    // will look least confusing in the source map.
    name: 'nx/core/package-json',
    createNodes: [
        '{project.json,**/project.json}',
        (file, _, { workspaceRoot }) => {
            const project = createProjectFromPackageJsonNextToProjectJson(file, workspaceRoot);
            return project
                ? {
                    projects: {
                        [project.name]: project,
                    },
                }
                : {};
        },
    ],
};
exports.default = exports.PackageJsonProjectsNextToProjectJsonPlugin;
function createProjectFromPackageJsonNextToProjectJson(projectJsonPath, workspaceRoot) {
    const root = (0, path_1.dirname)(projectJsonPath);
    const relativePackageJsonPath = (0, path_1.join)(root, 'package.json');
    const packageJsonPath = (0, path_1.join)(workspaceRoot, relativePackageJsonPath);
    const readJson = (f) => (0, fileutils_1.readJsonFile)((0, path_1.join)(workspaceRoot, f));
    // Do not create projects for package.json files
    // that are part of the package manager workspaces
    // Those package.json files will be processed later on
    const matcher = (0, package_json_workspaces_1.buildPackageJsonWorkspacesMatcher)(workspaceRoot, readJson);
    if (!(0, fs_1.existsSync)(packageJsonPath) || matcher(relativePackageJsonPath)) {
        return null;
    }
    try {
        const packageJson = (0, fileutils_1.readJsonFile)(packageJsonPath);
        let { nx, name } = packageJson;
        return {
            ...nx,
            name,
            root,
            targets: (0, package_json_1.readTargetsFromPackageJson)(packageJson),
            metadata: (0, package_json_1.getMetadataFromPackageJson)(packageJson),
            tags: (0, package_json_1.getTagsFromPackageJson)(packageJson),
        };
    }
    catch (e) {
        console.log(e);
        return null;
    }
}
